@@ -1,5 +1,5 @@
 # fmt: off
-##[[[cog
+# #[[[cog
 # import cog
 # from alfasim_sdk import CaseDescription
 # from alfasim_sdk._internal.alfacase.generate_schema import get_all_classes_that_needs_schema, generate_alfacase_schema
@@ -87,7 +87,14 @@ heat_source_equipment_description_schema = Map(
     {
         "start": Map({"value": Float(), "unit": Str()}),
         "length": Map({"value": Float(), "unit": Str()}),
-        "power": Map({"value": Float(), "unit": Str()}),
+        Optional("power_input_type"): Enum(['constant', 'curve']),
+        Optional("power"): Map({"value": Float(), "unit": Str()}),
+        Optional("power_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
     }
 )
 heavy_component_description_schema = Map(
@@ -136,20 +143,75 @@ linear_ipr_description_schema = Map(
     {
         Optional("well_index_phase"): Enum(['well_index_phase_gas', 'well_index_phase_oil', 'well_index_phase_water', 'well_index_phase_liquid']),
         Optional("min_pressure_difference"): Map({"value": Float(), "unit": Str()}),
+        Optional("well_index_input_type"): Enum(['constant', 'curve']),
         Optional("well_index"): Map({"value": Float(), "unit": Str()}),
+        Optional("well_index_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
     }
 )
 mass_source_equipment_description_schema = Map(
     {
         Optional("fluid"): Str(),
         Optional("tracer_mass_fraction"): Map({"values": Seq(Float()), "unit": Str()}),
+        Optional("temperature_input_type"): Enum(['constant', 'curve']),
         Optional("temperature"): Map({"value": Float(), "unit": Str()}),
+        Optional("temperature_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         Optional("source_type"): Enum(['mass_source_type_mass_flow_rates', 'mass_source_type_all_volumetric_flow_rates', 'mass_source_type_flow_rate_oil_gor_wc', 'mass_source_type_flow_rate_gas_gor_wc', 'mass_source_type_flow_rate_water_gor_wc', 'mass_source_type_total_mass_flow_rate_pvt_split']),
+        Optional("volumetric_flow_rates_std_input_type"): Enum(['constant', 'curve']),
         Optional("volumetric_flow_rates_std"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("volumetric_flow_rates_std_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("mass_flow_rates_input_type"): Enum(['constant', 'curve']),
         Optional("mass_flow_rates"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("mass_flow_rates_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("total_mass_flow_rate_input_type"): Enum(['constant', 'curve']),
         Optional("total_mass_flow_rate"): Map({"value": Float(), "unit": Str()}),
+        Optional("total_mass_flow_rate_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("water_cut_input_type"): Enum(['constant', 'curve']),
         Optional("water_cut"): Map({"value": Float(), "unit": Str()}),
+        Optional("water_cut_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("gas_oil_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_oil_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_oil_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         "position": Map({"value": Float(), "unit": Str()}),
     }
 )
@@ -157,13 +219,61 @@ mass_source_node_properties_description_schema = Map(
     {
         Optional("fluid"): Str(),
         Optional("tracer_mass_fraction"): Map({"values": Seq(Float()), "unit": Str()}),
+        Optional("temperature_input_type"): Enum(['constant', 'curve']),
         Optional("temperature"): Map({"value": Float(), "unit": Str()}),
+        Optional("temperature_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         Optional("source_type"): Enum(['mass_source_type_mass_flow_rates', 'mass_source_type_all_volumetric_flow_rates', 'mass_source_type_flow_rate_oil_gor_wc', 'mass_source_type_flow_rate_gas_gor_wc', 'mass_source_type_flow_rate_water_gor_wc', 'mass_source_type_total_mass_flow_rate_pvt_split']),
+        Optional("volumetric_flow_rates_std_input_type"): Enum(['constant', 'curve']),
         Optional("volumetric_flow_rates_std"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("volumetric_flow_rates_std_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("mass_flow_rates_input_type"): Enum(['constant', 'curve']),
         Optional("mass_flow_rates"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("mass_flow_rates_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("total_mass_flow_rate_input_type"): Enum(['constant', 'curve']),
         Optional("total_mass_flow_rate"): Map({"value": Float(), "unit": Str()}),
+        Optional("total_mass_flow_rate_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("water_cut_input_type"): Enum(['constant', 'curve']),
         Optional("water_cut"): Map({"value": Float(), "unit": Str()}),
+        Optional("water_cut_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("gas_oil_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_oil_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_oil_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
     }
 )
 material_description_schema = Map(
@@ -204,12 +314,6 @@ open_hole_description_schema = Map(
         "inner_roughness": Map({"value": Float(), "unit": Str()}),
     }
 )
-opening_curve_description_schema = Map(
-    {
-        Optional("time"): Map({"values": Seq(Float()), "unit": Str()}),
-        Optional("opening"): Map({"values": Seq(Float()), "unit": Str()}),
-    }
-)
 packer_description_schema = Map(
     {
         "name": Str(),
@@ -222,11 +326,12 @@ physics_description_schema = Map(
         Optional("hydrodynamic_model"): Enum(['hydrodynamic_model_2_fields', 'hydrodynamic_model_4_fields', 'hydrodynamic_model_3_layers_gas_oil_water', 'hydrodynamic_model_5_fields_solid', 'hydrodynamic_model_5_fields_water', 'hydrodynamic_model_5_fields_co2', 'hydrodynamic_model_3_layers_no_bubble_gas_oil_water', 'hydrodynamic_model_3_layers_water_with_co2', 'hydrodynamic_model_3_layers_7_fields_gas_oil_water', 'hydrodynamic_model_3_layers_9_fields_gas_oil_water']),
         Optional("simulation_regime"): Enum(['simulation_regime_transient', 'simulation_regime_steady_state']),
         Optional("energy_model"): Enum(['no_model', 'global_model', 'layers_model']),
-        Optional("solids_model"): Enum(['no_model', 'thomas1965_equilibrium', 'mills1985_equilibrium', 'santamaria2010_equilibrium']),
+        Optional("solids_model"): Enum(['no_model', 'thomas1965_equilibrium', 'mills1985_equilibrium', 'santamaria2010_equilibrium', 'from_plugin']),
+        Optional("solids_model_plugin_id"): Str(),
         Optional("initial_condition_strategy"): Enum(['constant', 'steady_state', 'restart']),
         Optional("restart_filepath"): Str(),
         Optional("keep_former_results"): Bool(),
-        Optional("emulsion_model"): Enum(['no_model', 'model_default', 'taylor1932', 'brinkman1952', 'mooney1951a', 'mooney1951b', 'hinze1955', 'sleicher1962', 'brauner2001', 'boxall2012', 'brinkman1952_and_yeh1964']),
+        Optional("emulsion_model"): Enum(['no_model', 'model_default', 'taylor1932', 'brinkman1952', 'mooney1951a', 'mooney1951b', 'hinze1955', 'sleicher1962', 'brauner2001', 'boxall2012', 'brinkman1952_and_yeh1964', 'from_plugin']),
         Optional("flash_model"): Enum(['hydrocarbon_only', 'hydrocarbon_and_water']),
         Optional("correlations_package"): Enum(['correlation_package_classical', 'correlation_package_alfasim', 'correlation_package_isdb_tests']),
     }
@@ -247,23 +352,78 @@ pressure_container_description_schema = Map(
 )
 pressure_node_properties_description_schema = Map(
     {
+        Optional("pressure_input_type"): Enum(['constant', 'curve']),
         Optional("pressure"): Map({"value": Float(), "unit": Str()}),
+        Optional("pressure_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("temperature_input_type"): Enum(['constant', 'curve']),
         Optional("temperature"): Map({"value": Float(), "unit": Str()}),
+        Optional("temperature_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         Optional("fluid"): Str(),
         Optional("tracer_mass_fraction"): Map({"values": Seq(Float()), "unit": Str()}),
         Optional("split_type"): Enum(['mass_inflow_split_type_constant_volume_fraction', 'mass_inflow_split_type_constant_mass_fraction', 'mass_inflow_split_type_pvt', 'mass_inflow_split_type_pvt_user_gor_wc', 'mass_inflow_split_type_pvt_user_glr_wc']),
+        Optional("mass_fractions_input_type"): Enum(['constant', 'curve']),
         Optional("mass_fractions"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("mass_fractions_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("volume_fractions_input_type"): Enum(['constant', 'curve']),
         Optional("volume_fractions"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("volume_fractions_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("gas_liquid_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_liquid_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_liquid_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("gas_oil_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_oil_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_oil_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("water_cut_input_type"): Enum(['constant', 'curve']),
         Optional("water_cut"): Map({"value": Float(), "unit": Str()}),
+        Optional("water_cut_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
     }
 )
 profile_output_description_schema = Map(
     {
         "curve_names": Seq(Str()),
         "element_name": Str(),
-        "location": Enum(['main', 'annulus']),
+        "location": Enum(['main', 'annulus', 'not_defined']),
     }
 )
 pvt_model_correlation_description_schema = Map(
@@ -311,16 +471,71 @@ referenced_volume_fractions_container_description_schema = Map(
 )
 reservoir_inflow_equipment_description_schema = Map(
     {
+        Optional("pressure_input_type"): Enum(['constant', 'curve']),
         Optional("pressure"): Map({"value": Float(), "unit": Str()}),
+        Optional("pressure_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("temperature_input_type"): Enum(['constant', 'curve']),
         Optional("temperature"): Map({"value": Float(), "unit": Str()}),
+        Optional("temperature_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         Optional("fluid"): Str(),
         Optional("tracer_mass_fraction"): Map({"values": Seq(Float()), "unit": Str()}),
         Optional("split_type"): Enum(['mass_inflow_split_type_constant_volume_fraction', 'mass_inflow_split_type_constant_mass_fraction', 'mass_inflow_split_type_pvt', 'mass_inflow_split_type_pvt_user_gor_wc', 'mass_inflow_split_type_pvt_user_glr_wc']),
+        Optional("mass_fractions_input_type"): Enum(['constant', 'curve']),
         Optional("mass_fractions"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("mass_fractions_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("volume_fractions_input_type"): Enum(['constant', 'curve']),
         Optional("volume_fractions"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("volume_fractions_curve"): MapPattern(
+            Str(),
+            Map(
+                {
+                    "image": Map({"values": Seq(Float()), "unit": Str()}),
+                    "domain": Map({"values": Seq(Float()), "unit": Str()}),
+                }
+            ),
+        ),
+        Optional("gas_liquid_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_liquid_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_liquid_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("gas_oil_ratio_input_type"): Enum(['constant', 'curve']),
         Optional("gas_oil_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("gas_oil_ratio_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("water_cut_input_type"): Enum(['constant', 'curve']),
         Optional("water_cut"): Map({"value": Float(), "unit": Str()}),
+        Optional("water_cut_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         "start": Map({"value": Float(), "unit": Str()}),
         "length": Map({"value": Float(), "unit": Str()}),
         Optional("productivity_ipr"): Str(),
@@ -333,9 +548,11 @@ separator_node_properties_description_schema = Map(
         Optional("geometry"): Enum(['vertical_cylinder', 'horizontal_cylinder', 'sphere']),
         Optional("length"): Map({"value": Float(), "unit": Str()}),
         Optional("overall_heat_transfer_coefficient"): Map({"value": Float(), "unit": Str()}),
-        Optional("radius"): Map({"value": Float(), "unit": Str()}),
+        Optional("diameter"): Map({"value": Float(), "unit": Str()}),
         Optional("nozzles"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
         Optional("initial_phase_volume_fractions"): MapPattern(Str(), Map({"value": Float(), "unit": Str()})),
+        Optional("gas_separation_efficiency"): Map({"value": Float(), "unit": Str()}),
+        Optional("liquid_separation_efficiency"): Map({"value": Float(), "unit": Str()}),
     }
 )
 speed_curve_description_schema = Map(
@@ -385,9 +602,9 @@ tracers_mass_fractions_container_description_schema = Map(
 trend_output_description_schema = Map(
     {
         "curve_names": Seq(Str()),
-        "element_name": Str(),
-        "position": Map({"value": Float(), "unit": Str()}),
-        "location": Enum(['main', 'annulus']),
+        "location": Enum(['main', 'annulus', 'not_defined']),
+        Optional("position"): Map({"value": Float(), "unit": Str()}),
+        Optional("element_name"): Str(),
     }
 )
 tubing_description_schema = Map(
@@ -566,7 +783,12 @@ valve_equipment_description_schema = Map(
         Optional("opening_type"): Enum(['constant_opening', 'table_interpolation']),
         Optional("opening"): Map({"value": Float(), "unit": Str()}),
         Optional("opening_curve_interpolation_type"): Enum(['constant', 'linear', 'quadratic']),
-        Optional("opening_curve"): opening_curve_description_schema,
+        Optional("opening_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
         Optional("cv_table"): cv_table_description_schema,
     }
 )
@@ -678,5 +900,5 @@ case_description_schema = Map(
         Optional("walls"): Seq(wall_description_schema),
     }
 )
-# [[[end]]] (checksum: 246db83b8565903de6db4af4b62191c7)
+# [[[end]]] (checksum: 710fb058c518db160703194f4a2e87fc)
 # fmt: on
