@@ -97,7 +97,7 @@ def finalize(ctx: "void*") -> "int":
         {
             // Threads information
             int n_threads = -1;
-            int errcode = alfasim.get_number_of_threads(ctx, &n_threads);
+            int errcode = alfasim_sdk_api.get_number_of_threads(ctx, &n_threads);
             f (errcode != 0){ // or errcode != OK
                 return errcode;
             }
@@ -105,7 +105,7 @@ def finalize(ctx: "void*") -> "int":
             // Plugin internal data
             for (int thread_id = 0; thread_id < n_threads; ++thread_id) {
                 void* data = nullptr;
-                errcode = alfasim.get_plugin_data(
+                errcode = alfasim_sdk_api.get_plugin_data(
                     ctx, &data, plugin_id, thread_id);
                 delete data;
             }
@@ -322,13 +322,13 @@ def calculate_mass_source_term(
         HOOK_CALCULATE_MASS_SOURCE_TERM(
             ctx, mass_source, n_fields, n_control_volumes)
         {
-            int liq_id = -1;
+            int oil_id = -1;
             errcode = alfasim_sdk_api.get_field_id(
                 ctx, &oil_id, "oil");
             // Convertion from void* to double* and getting the
             // array range related to oil field
             double* oil_mass_source =
-                (double*) mass_source + n_control_volumes * liq_id;
+                (double*) mass_source + n_control_volumes * oil_id;
             // Make some calculations and add it to oil_mass_source.
             // In this example, we add a mass source of 3.1415 kg/s to all control volumes.
             for (int i = 0; i < n_control_volumes; ++i) {
@@ -509,12 +509,14 @@ def initialize_state_variables_calculator(
     P: "void*",
     T: "void*",
     T_mix: "void*",
+    phi: "void*",
     n_control_volumes: "int",
     n_layers: "int",
+    n_tracers: "int",
 ) -> "int":
     """
     **c++ signature** : ``HOOK_INITIALIZE_STATE_VARIABLES_CALCULATOR(void* ctx, void* P, void* T, void* T_mix,
-    int n_control_volumes, int n_layers)``
+    void* phi, int n_control_volumes, int n_layers, int n_tracers)``
 
     Hook for the state variables calculator initialization (internal ``ALFAsim`` structure).
 
@@ -526,12 +528,15 @@ def initialize_state_variables_calculator(
     :param P: Pressure values array
     :param T: Temperature values array
     :param T_mix: Mixture temperature values array
+    :param phi: Tracer mass fraction values array
     :param n_control_volumes: Number of control volumes
     :param n_layers: Number of layers
+    :param n_tracers: Number of tracers in the system
     :returns: Return OK if successful or anything different if failed
 
     The ``P`` and ``T_mix`` have size equal to ``n_control_volumes``. However, ``T`` has values contiguous in memory
-    and its dimensions are given by ``n_layers`` and ``n_control_volumes``
+    and its dimensions are given by ``n_layers`` and ``n_control_volumes``. Finally, ``phi`` dimensions are given by
+    ``n_tracers`` and ``n_control_volumes``.
 
     Example of usage:
 
@@ -540,8 +545,7 @@ def initialize_state_variables_calculator(
         :emphasize-lines: 1
 
         HOOK_INITIALIZE_STATE_VARIABLES_CALCULATOR(
-            void* ctx, void* P, void* T, void* T_mix,
-            int n_control_volumes, int n_layers)
+            ctx, P, T, T_mix, phi, n_control_volumes, n_layers, n_tracers)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -562,8 +566,7 @@ def initialize_state_variables_calculator(
         }
         // Then, to use the cached value:
         HOOK_CALCULATE_STATE_VARIABLE(
-            void* ctx, void* P, void* T, int n_control_volumes, i
-            nt n_layers, int phase_id, int property_id, void* output)
+            ctx, P, T, n_control_volumes, n_layers, phase_id, property_id, output)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -644,9 +647,7 @@ def calculate_state_variable(
         :emphasize-lines: 1
 
         HOOK_CALCULATE_STATE_VARIABLE(
-            void* ctx, void* P, void* T,
-            int n_control_volumes, int n_layers,
-            int phase_id, int property_id, void* output)
+            ctx, P, T, n_control_volumes, n_layers, phase_id, property_id, output)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -695,7 +696,7 @@ def calculate_phase_pair_state_variable(
     **c++ signature** : ``HOOK_CALCULATE_PHASE_PAIR_STATE_VARIABLE(void* ctx, void* P, void* T_mix, int n_control_volumes,
     int phase1_id, int phase2_id, int property_id, void* output)``
 
-    Hook to calculate the state variable given by the `property_id` (See :cpp:enum:StateVariable values), for the phase
+    Hook to calculate the state variable given by the `property_id` (See :cpp:enum:`StateVariable` values), for the phase
     pair `(phase1_id, phase2_id)` (Note that the phase id is the same as the one retrieved from the :cpp:func:`get_phase_id()`
     API function - It is not advisable to use hardcoded numbers).
 
@@ -724,8 +725,7 @@ def calculate_phase_pair_state_variable(
         :emphasize-lines: 1
 
         HOOK_CALCULATE_PHASE_PAIR_STATE_VARIABLE(
-            void* ctx, void* P, void* T_mix, int n_control_volumes,
-            int phase1_id, int phase2_id, int property_id, void* output)
+            ctx, P, T_mix, n_control_volumes, phase1_id, phase2_id, property_id, output)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -787,7 +787,7 @@ def finalize_state_variables_calculator(ctx: "void*") -> "int":
         :linenos:
         :emphasize-lines: 1
 
-        HOOK_FINALIZE_STATE_VARIABLES_CALCULATOR(void* ctx)
+        HOOK_FINALIZE_STATE_VARIABLES_CALCULATOR(ctx)
         {
             return OK;
         }
@@ -823,8 +823,7 @@ def initialize_particle_diameter_of_solids_fields(
         :emphasize-lines: 1
 
         HOOK_INITIALIZE_PARTICLE_DIAMETER_OF_SOLIDS_FIELDS(
-            void* ctx, void* particle_diameter,
-            int n_control_volumes, int solids_field_id)
+            ctx, particle_diameter, n_control_volumes, solids_field_id)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -841,11 +840,11 @@ def initialize_particle_diameter_of_solids_fields(
             } else {
                 for (int i = 0; i < n_control_volumes; ++i) {
                     // If the particle size is constant
-                    output[i] = data.constant_particle_size;
+                    particle_diameter[i] = data.constant_particle_size;
                     // The value is calculated
                     // MyStruct has a function
                     // called 'initial_particle_size()'
-                    output[i] = data.initial_particle_size(
+                    particle_diameter[i] = data.initial_particle_size(
                              // List of params that can be
                              // retrieved by get_simulation_array()
                              );
@@ -885,8 +884,7 @@ def update_particle_diameter_of_solids_fields(
         :emphasize-lines: 1
 
         HOOK_UPDATE_PARTICLE_DIAMETER_OF_SOLIDS_FIELDS(
-            void* ctx, void* particle_diameter,
-            int n_control_volumes, int solids_field_id)
+            ctx, particle_diameter, n_control_volumes, solids_field_id)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -903,11 +901,11 @@ def update_particle_diameter_of_solids_fields(
             } else {
                 for (int i = 0; i < n_control_volumes; ++i) {
                     // If the particle size is constant
-                    output[i] = data.constant_particle_size;
+                    particle_diameter[i] = data.constant_particle_size;
                     // The value is calculated
                     // MyStruct has a function
                     // called 'compute_particle_size()'
-                    output[i] = data.compute_particle_size(
+                    particle_diameter[i] = data.compute_particle_size(
                              // List of params that can be
                              // retrieved by get_simulation_array()
                              );
@@ -921,50 +919,147 @@ def update_particle_diameter_of_solids_fields(
 
 def calculate_slip_velocity(
     ctx: "void*",
-    U_fields: "void*",
-    alpha_f: "void*",
-    d_disp_fields: "void*",
-    P: "void*",
-    rho_f: "void*",
-    mu_f: "void*",
-    sin_theta_f: "void*",
-    delta_x_f: "void*",
+    U_slip: "double*",
+    solid_field_index: "int",
+    layer_index: "int",
+    n_faces: "int",
 ) -> "int":
     """
-    Internal simulator hook to calculate slip velocity between fluids
-    and solid phase.
+    **c++ signature** : ``HOOK_CALCULATE_SLIP_VELOCITY(void* ctx, double* U_slip, int solid_field_index, int layer_index, int n_faces)``
+
+    Internal `hook` to calculate slip velocity in the Solids Model.
+    This `hook` will be used in the solids model to calculate the slip velocity between
+    fluid and solid phase.
+
+    The output variable ``U_slip`` is the slip velocity with size equal to ``n_faces`` and it
+    is dimensionless.
+    The ``solid_field_index`` is the index of the dispersed solid field.
+    The ``layer_index`` is the index of the layer and continuous field in the layer (in which the solid
+    field is dispersed).
+
+    .. Note::
+        It is important to know that the calculations for velocity is performed over the faces (see
+        ``n_faces`` param). For that, any variable that should be retrieved using :cpp:func:`get_simulation_array`
+        must be use value ``FACE`` in the :cpp:enum:`GridScope` param.
 
     :param ctx: ALFAsim's plugins context
-    :param U_fields: Field velocities,
-    :param alpha_f: Field Volume fractions on faces,
-    :param d_disp_fields: Diameter of dispersed fields,
-    :param P: Pressure,
-    :param rho_f: Field densities on faces,
-    :param mu_f: Field viscosities on faces,
-    :param sin_theta_f: Sin of Theta on faces in which Theta is the angle between the Pipe and the Y-Axis,
-    :param delta_x_f: The control volume lenght related to the faces,
+    :param U_slip: Slip velocity between fluid and solid phase
+    :param solid_field_index: Index of the dispersed solid field
+    :param layer_index: Index of the Layer or Continuous Field
+    :param n_faces: Number of faces.
 
     :returns: Return OK if successful or anything different if failed
 
-    It is expected to be changed the U_fields of solid phase, whose index will be available via API.
+    Example of usage:
+
+    .. code-block:: c++
+        :linenos:
+        :emphasize-lines: 1
+
+        HOOK_CALCULATE_SLIP_VELOCITY(ctx, U_slip, disp_field_index, layer_index, n_faces)
+        {
+            const char* plugin_id = get_plugin_id()
+            errcode = alfasim_sdk_api.get_thread_id(ctx, &thread_id);
+            if (errcode != OK) {
+                return errcode;
+            }
+            // MyStruct is a developer defined struct to hold
+            // all important information for plugin hooks.
+            MyStruct* data = nullptr;
+            errcode = alfasim_sdk_api.get_plugin_data(ctx, (void**) &data, plugin_id, thread_id);
+            if (errcode != OK) {
+                return errcode;
+            }
+
+            // compute the slip velocity using your own correlation
+            for (int i = 0; i < n_faces; ++i){
+                U_slip[i] = slip_velocity[i];
+            }
+
+            return OK;
+        }
     """
 
 
-def calculate_slurry_viscosity(
-    ctx: "void*", alpha_f: "void*", mu_f: "void*", mu_f_layer: "void*"
+def calculate_relative_slurry_viscosity(
+    ctx: "void*",
+    mu_r: "double*",
+    solid_field_index: "int",
+    layer_index: "int",
+    n_faces: "int",
 ) -> "int":
     """
-    Internal simulator hook to calculate slurry viscosity of layer(s).
+    **c++ signature** : ``HOOK_RELATIVE_SLURRY_VISCOSITY(void* ctx, double* mu_r, int solid_field_index, int layer_index, int n_faces)``
+
+    Internal `hook` to calculate the relative slurry viscosity in the Solids Model.
+    This `hook` will be used in the Solids model to calculate the effective viscosity of the slurry
+    (solid field + continuous field).
+
+    The relative slurry viscosity is defined by:
+
+    .. math::
+
+        \\begin{equation}
+            \\mu_r = \\frac{\\mu_{eff}}{\\mu_c}
+        \\end{equation}
+
+
+    .. rubric:: Where
+
+    :1: :math:`\\mu_r` is the relative emulsion viscosity
+    :2: :math:`\\mu_{eff}` is the effective viscosity
+    :3: :math:`\\mu_c` is the viscosity of the continuous field
+
+    The output variable ``mu_r`` is the relative slurry viscosity with size equal to ``n_faces`` and it
+    is dimensionless.
+    The ``solid_field_index`` is the index of the dispersed solid field.
+    The ``layer_index`` is the index of the layer and continuous field in the layer (in which the solid
+    field is dispersed).
+
+    .. Note::
+        It is important to know that the calculations for viscosity is performed over the faces (see
+        ``n_faces`` param). For that, any variable that should be retrieved using :cpp:func:`get_simulation_array`
+        must be use value ``FACE`` in the :cpp:enum:`GridScope` param.
+
+    This `hook` allows the implementation of the relative slurry viscosity correlation. Once the plugin
+    installed it is important to be selected in the solids model configuration inside the Physics data
+    tree in the ALFAsim application in order to be used.
 
     :param ctx: ALFAsim's plugins context
-    :param alpha_f: Fields Volume fractions on faces,
-    :param mu_f: Field viscosities on faces,
-    :param mu_f_layer: Layer Viscosities on faces,
-
+    :param mu_r: Relative slurry viscosity
+    :param solid_field_index: Index of the dispersed solid field
+    :param layer_index: Index of the Layer or Continuous Field
+    :param n_faces: Number of faces.
     :returns: Return OK if successful or anything different if failed
 
-    It is expected to be changed the mu_f_layer of oil layer(continuous oil and dispersed solid),
-    whose index will be available via API.
+    Example of usage:
+
+    .. code-block:: c++
+        :linenos:
+        :emphasize-lines: 1
+
+        HOOK_RELATIVE_SLURRY_VISCOSITY(ctx, mu_r, solid_field_index, layer_index, n_faces)
+        {
+            const char* plugin_id = get_plugin_id()
+            errcode = alfasim_sdk_api.get_thread_id(ctx, &thread_id);
+            if (errcode != OK) {
+                return errcode;
+            }
+            // MyStruct is a developer defined struct to hold
+            // all important information for plugin hooks.
+            MyStruct* data = nullptr;
+            errcode = alfasim_sdk_api.get_plugin_data(ctx, (void**) &data, plugin_id, thread_id);
+            if (errcode != OK) {
+                return errcode;
+            }
+
+            // compute the relative slurry viscosity using your own correlation
+            for (int i = 0; i < n_faces; ++i){
+                mu_r[i] = relative_slurry_viscosity[i];
+            }
+
+            return OK;
+        }
     """
 
 
@@ -990,7 +1085,7 @@ def initialize_mass_fraction_of_tracer(
         :emphasize-lines: 1
 
         HOOK_INITIALIZE_MASS_FRACTION_OF_TRACER(
-            void* ctx, void* phi_initial, int tracer_index)
+            ctx, phi_initial, tracer_index)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -1047,8 +1142,7 @@ def calculate_mass_fraction_of_tracer_in_phase(
         :emphasize-lines: 1
 
         HOOK_CALCULATE_MASS_FRACTION_OF_TRACER_IN_PHASE(
-            void* ctx, void* phi, void* phi_phase,
-            int tracer_index, int phase_index, int n_control_volumes)
+            ctx, phi, phi_phase, tracer_index, phase_index, n_control_volumes)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -1127,9 +1221,8 @@ def calculate_mass_fraction_of_tracer_in_field(
         :emphasize-lines: 1
 
         HOOK_CALCULATE_MASS_FRACTION_OF_TRACER_IN_FIELD(
-            void* ctx, void* phi_phase, void* phi_field,
-            int tracer_index, int field_index,
-            int phase_index_of_field, int n_control_volumes)
+            ctx, phi_phase, phi_field, tracer_index, field_index,
+            phase_index_of_field, n_control_volumes)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -1201,7 +1294,7 @@ def set_prescribed_boundary_condition_of_mass_fraction_of_tracer(
         :emphasize-lines: 1
 
         HOOK_SET_PRESCRIBED_BOUNDARY_CONDITION_OF_MASS_FRACTION_OF_TRACER(
-            void* ctx, void* phi_presc, int tracer_index)
+            ctx, phi_presc, tracer_index)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -1260,7 +1353,7 @@ def update_boundary_condition_of_mass_fraction_of_tracer(
         :emphasize-lines: 1
 
         HOOK_UPDATE_BOUNDARY_CONDITION_OF_MASS_FRACTION_OF_TRACER(
-            void* ctx, void* phi_presc, int tracer_index)
+            ctx, phi_presc, tracer_index)
         {
             // getting plugin internal data
             int errcode = -1;
@@ -1324,8 +1417,7 @@ def calculate_ucm_friction_factor_stratified(
         :linenos:
         :emphasize-lines: 1
 
-        int HOOK_CALCULATE_UCM_FRICTION_FACTOR_STRATIFIED(
-            void* ctx, double* ff_wG, double* ff_wL, double* ff_i)
+        HOOK_CALCULATE_UCM_FRICTION_FACTOR_STRATIFIED(ctx, ff_wG, ff_wL, ff_i)
         {
             int errcode = -1;
             int G = TwoPhaseSystem::GAS;
@@ -1336,7 +1428,7 @@ def calculate_ucm_friction_factor_stratified(
             errcode = alfasim_sdk_api.get_ucm_friction_factor_input_variable(
                 ctx, &alpha[G], "alpha", TwoPhaseSystem::GAS);
             if (errcode != OK){ return errcode; }
-            errcode = alfasim_plugins_api.get_ucm_friction_factor_input_variable(
+            errcode = alfasim_sdk_api.get_ucm_friction_factor_input_variable(
                 ctx, &alpha[L], "alpha", TwoPhaseSystem::LIQUID);
             if (errcode != OK){ return errcode; }
             // And so on to each friction factor input variable
@@ -1403,7 +1495,7 @@ def calculate_liq_liq_flow_pattern(
 
     .. note::
         The main input variables needed to estimate the flow pattern is available in the API function
-        :cpp:func:`get_ucm_liqliq_flow_pattern_input_variable`. Note that, the variables listed in the documentation
+        :cpp:func:`get_liq_liq_flow_pattern_input_variable`. Note that, the variables listed in the documentation
         of the cited function are related to one control volume, in which the estimation is applied.
 
     This `hook` allows the developer to implement your own flow pattern estimation algorithm for the liquid-liquid
@@ -1415,8 +1507,8 @@ def calculate_liq_liq_flow_pattern(
     - `2 - Dispersed Oil`: Dispersed oil in continuous water. |br|
     - `3 - Dispersed Water`: Dispersed water in continuous Oil. |br|
     - `4 - Separated`: Separated continuous oil and continuous water. |br|
-    - `5 - separated Mixed`: Separated with dispersed oil and water droplets. |br|
-    - `6 - separated Wavy`: Separated with waves. |br|
+    - `5 - Separated Wavy`: Separated with waves. |br|
+    - `6 - Separated Mixed`: Separated with dispersed oil and water droplets. |br|
 
     Any value different from these values will be assumed an `Unknown` flow pattern.
 
@@ -1431,7 +1523,7 @@ def calculate_liq_liq_flow_pattern(
         :linenos:
         :emphasize-lines: 1
 
-        int HOOK_CALCULATE_LIQ_LIQ_FLOW_PATTERN(void* ctx, int* ll_fp, double* water_vol_frac)
+        HOOK_CALCULATE_LIQ_LIQ_FLOW_PATTERN(ctx, ll_fp, water_vol_frac)
         {
             int errcode = -1;
             int O = LiquidLiquidSystem::OIL;
@@ -1439,10 +1531,10 @@ def calculate_liq_liq_flow_pattern(
 
             // Getting liq-liq Flow Pattern input data from context
             double rho[2];
-            errcode = alfasim_sdk_api.get_ucm_liqliq_flow_pattern_input_variable(
+            errcode = alfasim_sdk_api.get_liq_liq_flow_pattern_input_variable(
                 ctx, &rho[O], "rho", LiquidLiquidSystem::OIL);
             if (errcode != OK){ return errcode; }
-            errcode = alfasim_plugins_api.get_ucm_liqliq_flow_pattern_input_variable(
+            errcode = alfasim_sdk_api.get_liq_liq_flow_pattern_input_variable(
                 ctx, &rho[W], "rho", LiquidLiquidSystem::WATER);
             if (errcode != OK){ return errcode; }
             // And so on to each input variable
@@ -1452,7 +1544,6 @@ def calculate_liq_liq_flow_pattern(
             // Estimate the liquid-liquid Flow pattern and volume fraction of water
             // using your own algorithm.
 
-
             *ll_fp = flow_pattern;
             *water_vol_frac = alpha_W;
 
@@ -1473,7 +1564,7 @@ def calculate_liquid_effective_viscosity(
 
     .. note::
         The main input variables needed to estimate the liquid effective viscosity is available in the API function
-        :cpp:func:`get_ucm_liquid_effective_viscosity_input_variable`. Note that, the variables listed in the
+        :cpp:func:`get_liquid_effective_viscosity_input_variable`. Note that, the variables listed in the
         documentation of the cited function are related to one control volume, in which the estimation is applied.
 
     This `hook` allows the developer to implement your own liquid effective viscosity correlation to
@@ -1490,7 +1581,7 @@ def calculate_liquid_effective_viscosity(
         :linenos:
         :emphasize-lines: 1
 
-        int HOOK_CALCULATE_LIQUID_EFFECTIVE_VISCOSITY(void* ctx, double* mu_l_eff, int ll_fp)
+        HOOK_CALCULATE_LIQUID_EFFECTIVE_VISCOSITY(ctx, mu_l_eff, ll_fp)
         {
             int errcode = -1;
             int O = LiquidLiquidSystem::OIL;
@@ -1498,10 +1589,10 @@ def calculate_liquid_effective_viscosity(
 
             // Getting liquid Effective Viscosity input data from context
             double rho[2];
-            errcode = alfasim_sdk_api.get_ucm_liquid_effecticve_viscosity_input_variable(
+            errcode = alfasim_sdk_api.get_liquid_effecticve_viscosity_input_variable(
                 ctx, &rho[O], "rho", LiquidLiquidSystem::OIL);
             if (errcode != OK){ return errcode; }
-            errcode = alfasim_plugins_api.get_ucm_liquid_effecticve_viscosity_input_variable(
+            errcode = alfasim_sdk_api.get_liquid_effecticve_viscosity_input_variable(
                 ctx, &rho[W], "rho", LiquidLiquidSystem::WATER);
             if (errcode != OK){ return errcode; }
             // And so on to each input variable
@@ -1531,7 +1622,7 @@ def calculate_gas_liq_surface_tension(
 
     .. note::
         The main input variables needed to estimate the Gas-Liquid Surface Tension is available in the API function
-        :cpp:func:`get_ucm_gasliq_surface_tension_input_variable`. Note that, the variables listed in the
+        :cpp:func:`get_gas_liq_surface_tension_input_variable`. Note that, the variables listed in the
         documentation of the cited function are related to one control volume, in which the estimation is applied.
 
     This `hook` allows the developer to implement your own Gas-liquid Surface Tension correlation for
@@ -1553,7 +1644,7 @@ def calculate_gas_liq_surface_tension(
         :linenos:
         :emphasize-lines: 1
 
-        int HOOK_CALCULATE_GAS_LIQ_SURFACE_TENSION(void* ctx, double* sigma_gl, int ll_fp)
+        HOOK_CALCULATE_GAS_LIQ_SURFACE_TENSION(ctx, sigma_gl, ll_fp)
         {
             int errcode = -1;
             int O = LiquidLiquidSystem::OIL;
@@ -1561,7 +1652,7 @@ def calculate_gas_liq_surface_tension(
 
             // Getting liquid Effective Viscosity input data from context
             double sigma_gll[2];
-            errcode = alfasim_sdk_api.get_ucm_gasliq_surface_tension_input_variable(
+            errcode = alfasim_sdk_api.get_gas_liq_surface_tension_input_variable(
                 ctx, &sigma_gll[O], "sigma_gll", LiquidLiquidSystem::OIL);
             if (errcode != OK){ return errcode; }
             // And so on to each input variable
@@ -1596,7 +1687,7 @@ def calculate_liq_liq_shear_force_per_volume(
 
     .. note::
         The main input variables needed to estimate the Shear Force is available in the API function
-        :cpp:func:`get_ucm_liqliq_shear_force_per_volume_input_variable`. Note that, the variables listed in the
+        :cpp:func:`get_liq_liq_shear_force_per_volume_input_variable`. Note that, the variables listed in the
         documentation of the cited function are related to one control volume, in which the estimation is applied.
 
     The output variable ``shear_w`` is the Wall Shear Force per unit Volume with size equal to ``2``
@@ -1632,8 +1723,8 @@ def calculate_liq_liq_shear_force_per_volume(
         :linenos:
         :emphasize-lines: 1
 
-        int HOOK_CALCULATE_LIQ_LIQ_SHEAR_FORCE_PER_VOLUME(void* ctx, double* shear_w,
-            double* shear_i, double* U_fields, double* vol_frac_fields, int ll_fp)
+        HOOK_CALCULATE_LIQ_LIQ_SHEAR_FORCE_PER_VOLUME(ctx, shear_w,
+            shear_i, U_fields, vol_frac_fields, ll_fp)
         {
             int errcode = -1;
             int O = 0;
@@ -1643,9 +1734,10 @@ def calculate_liq_liq_shear_force_per_volume(
 
             // Getting shear term input data from context
             double rho[2];
-            errcode = alfasim_sdk_api.get_ucm_liqliq_shear_force_per_volume_input_variable(
+            errcode = alfasim_sdk_api.get_liq_liq_shear_force_per_volume_input_variable(
                 ctx, &rho[O], "rho", LiquidLiquidSystem::OIL);
-            errcode = alfasim_sdk_api.get_ucm_liqliq_shear_force_per_volume_input_variable(
+            if (errcode != OK){ return errcode; }
+            errcode = alfasim_sdk_api.get_liq_liq_shear_force_per_volume_input_variable(
                 ctx, &rho[W], "rho", LiquidLiquidSystem::WATER);
             if (errcode != OK){ return errcode; }
             // And so on to each input variable
@@ -1672,6 +1764,95 @@ def calculate_liq_liq_shear_force_per_volume(
     """
 
 
+def calculate_relative_emulsion_viscosity(
+    ctx: "void*",
+    mu_r: "double*",
+    mu_disp: "double",
+    mu_cont: "double",
+    alpha_disp_in_layer: "double",
+    disp_field_index: "int",
+    cont_field_index: "int",
+) -> "int":
+    """
+    **c++ signature** : ``HOOK_RELATIVE_EMULSION_VISCOSITY(void* ctx, double* mu_r, double mu_disp, double mu_cont, double alpha_disp_in_layer)``
+
+    Internal `hook` to calculate the relative emulsion viscosity in the Emulsion Model.
+    This `hook` will be used in the emulsion model to calculate the apparent viscosity of the emulsion
+    (Continuous field + dispersed field = layer).
+
+    The relative emulsion viscosity is defined by:
+
+    .. math::
+
+        \\begin{equation}
+            \\mu_r = \\frac{\\mu_m}{\\mu_c}
+        \\end{equation}
+
+
+    .. rubric:: Where
+
+    :1: :math:`\\mu_r` is the relative emulsion viscosity
+    :2: :math:`\\mu_m` is the apparent viscosity
+    :3: :math:`\\mu_c` is the viscosity of the continuous field
+
+    The output variable ``mu_r`` is the relative emulsion viscosity, ``mu_disp`` is the dispersed field
+    viscosity, ``mu_cont`` is the continuous field viscosity and ``alpha_disp_in_layer`` is the volume
+    fraction of dispersed field in the layer. Finally ``disp_field_index`` and ``cont_field_index`` are
+    the Dispersed and Continuous Field indexes of the emulsion, respectively.
+
+    This `hook` allows the implementation of the relative emulsion viscosity correlation. Once the plugin
+    installed it is important to be selected in the emulsion model configuration inside the Physics data
+    tree in the ALFAsim application in order to be used.
+
+    :param ctx: ALFAsim's plugins context
+    :param mu_r: Relative emulsion viscosity
+    :param mu_disp: Dispersed field viscosity
+    :param mu_cont: Continuous field viscosity
+    :param alpha_disp_in_layer: Volume fraction of dispersed field in layer.
+    :param disp_field_index: Index of the dispersed field
+    :param cont_field_index: Index of the continuous field
+
+    :returns: Return OK if successful or anything different if failed
+
+    Example of usage:
+
+    .. code-block:: c++
+        :linenos:
+        :emphasize-lines: 1
+
+        HOOK_RELATIVE_EMULSION_VISCOSITY(ctx, mu_r, mu_disp, mu_cont, alpha_disp_in_layer)
+        {
+            int water_in_oil_id = -1;
+            errcode = alfasim_sdk_api.get_field_id(ctx, &water_in_oil_id, "water in oil");
+            if (errcode != OK) {
+                return errcode;
+            }
+
+            int oil_in_water_id = -1;
+            errcode = alfasim_sdk_api.get_field_id(ctx, &oil_in_water_id, "oil in water");
+            if (errcode != OK) {
+                return errcode;
+            }
+
+            if (disp_field_index == oil_in_water_id){
+                // Calculate the relative emulsion viscosity
+                // for water dominated scenario.
+                // ComputeForWaterDominated is a function implemented
+                // by plugin developer
+                ComputeForWaterDominated(mu_r, mu_disp, mu_cont);
+            } else if (disp_field_index == water_in_oil_id){
+                // Calculate the relative emulsion viscosity
+                // for oil dominated scenario
+                // ComputeForOilDominated is a function implemented
+                // by plugin developer
+                ComputeForOilDominated(mu_r, n_faces);
+            }
+
+            return OK;
+        }
+    """
+
+
 def friction_factor(v1: "int", v2: "int") -> "int":
     """
     Docs for Friction Factor
@@ -1835,8 +2016,9 @@ specs = HookSpecs(
         # Hooks related to solids phases
         initialize_particle_diameter_of_solids_fields,
         update_particle_diameter_of_solids_fields,
+        # Hooks related to Solids Model
         calculate_slip_velocity,
-        calculate_slurry_viscosity,
+        calculate_relative_slurry_viscosity,
         # Hooks related to Tracer added by plugin
         initialize_mass_fraction_of_tracer,
         calculate_mass_fraction_of_tracer_in_phase,
@@ -1851,6 +2033,8 @@ specs = HookSpecs(
         calculate_liquid_effective_viscosity,
         calculate_gas_liq_surface_tension,
         calculate_liq_liq_shear_force_per_volume,
+        # Hooks related to Emulsion Model
+        calculate_relative_emulsion_viscosity,
         # Extra Hooks (For testing)
         friction_factor,
         env_temperature,
