@@ -82,6 +82,7 @@ typedef int (*get_tracer_partition_coefficient_func)(void* ctx, double* out, voi
 typedef int (*get_plugin_input_data_multiplereference_selected_size_func)(void* ctx, int* indexes_size, const char* plugin_id, const char* var_name);
 typedef int (*get_input_variable_func)(void* ctx, double* out, const char* var_name, int phase_id);
 typedef int (*get_ucm_fluid_geometrical_properties_func)(void* ctx, double* S_w, double* S_i, double* H, double alpha_G, double D);
+typedef int (*get_relative_emulsion_viscosity_func)(void* ctx, double* out, double mu_disp, double mu_cont, double alpha_disp_in_layer, int disp_field_id, int cont_field_id);
 
 struct ALFAsimSDK_API {
 #if defined(_WIN32)
@@ -143,6 +144,8 @@ struct ALFAsimSDK_API {
     get_input_variable_func get_gas_liq_surface_tension_input_variable;
     get_input_variable_func get_liq_liq_shear_force_per_volume_input_variable;
 
+    get_relative_emulsion_viscosity_func get_relative_emulsion_viscosity;
+
 };
 
 #endif
